jQuery(function ($) {
  if (window.CodeMirror) {
    $(".gust-cm").each(function (_idx, el) {
      CodeMirror.fromTextArea(el, {
        mode: "application/json",
        lineNumbers: true,
        lineWrapping: true,
        indentWithTabs: false,
        tabSize: 2,
        theme: "darcula",
        lint: true,
        gutters: ["CodeMirror-lint-markers"],
      });
    });
  }

  var rebuildState = {
    loading: false,
    devCompileId: null,
    prodCompileId: null,
  };
  const setRebuildLoading = (loading) => {
    var btn = $("#gust-rebuild-css");
    if (loading) {
      rebuildState.loading = true;
      btn.text("Building...");
    } else {
      rebuildState.loading = false;
      btn.text("Rebuild CSS");
    }
  };

  const finishCompilation = (dev) => {
    if (dev) {
      rebuildState.devCompileId = null;
    } else {
      rebuildState.prodCompileId = null;
    }
    if (
      rebuildState.prodCompileId === null &&
      rebuildState.devCompileId === null
    ) {
      setRebuildLoading(false);
    }
  };

  const pollForUpdate = (dev) => {
    const compilationId = dev
      ? rebuildState.devCompileId
      : rebuildState.prodCompileId;

    $.ajax({
      type: "post",
      url: window.Gust.adminUrl,
      data: {
        nonce: window.Gust.nonce,
        action: "gust_check_compilation",
        compilationId,
      },
    })
      .then((response) => {
        if (response.retry) {
          setTimeout(() => {
            pollForUpdate(dev);
          }, 1000);
          return;
        }
        finishCompilation(dev);
      })
      .catch((e) => {
        console.log(e);
        finishCompilation(dev);
      });
  };

  $("#gust-rebuild-css").click(function (e) {
    e.preventDefault();
    if (rebuildState.loading) return;
    setRebuildLoading(true);
    $.ajax({
      type: "post",
      url: window.Gust.adminUrl,
      data: {
        nonce: window.Gust.nonce,
        action: "gust_request_compilation",
      },
    })
      .then((response) => {
        if (response.dev) {
          rebuildState.devCompileId = response.dev;
          pollForUpdate(true);
        }
        if (response.prod) {
          rebuildState.prodCompileId = response.prod;
          pollForUpdate(false);
        }
      })
      .catch((e) => {
        console.log(e);
        setRebuildLoading(false);
      });
  });
});
